@@ -1,6 +1,5 @@
 # -*- coding:utf-8 -*-
 
-from types import DictType
 from collections import defaultdict
 
 from grapheekdb.lib.undef import UNDEFINED
@@ -188,9 +187,9 @@ class EntityAggregate(object):
             counters[entity_id] += value
             total += value
         if total and (self._agg == '%'):
-            for entity_id, value in counters.items():
+            for entity_id, value in list(counters.items()):
                 counters[entity_id] = float(counters[entity_id]) / float(total)  # This may raise an exception, it's up to the user to handle it...
-        ordered_counters = sorted(counters.items(), key=lambda t: t[1] * self._mult)
+        ordered_counters = sorted(list(counters.items()), key=lambda t: t[1] * self._mult)
         results = []
         for entity_id, count in ordered_counters:
             entity = self._graph._item_from_id(self._entity_kind, entity_id)
@@ -200,11 +199,15 @@ class EntityAggregate(object):
     def __iter__(self):
         return self
 
-    def next(self):
+    def next(self):  # pragma : no cover
+        # Python 2 compatibility
+        return self.__next__()
+
+    def __next__(self):
         if self._current_iteration is None:
             self._current_iteration = iter(self._get_results())
         try:
-            return self._current_iteration.next()
+            return next(self._current_iteration)
         except StopIteration:
             self._current_iteration = None
         raise StopIteration
@@ -288,10 +291,14 @@ class EntityIterator(object):
         return current_iterator
 
     def next(self):
+        # Python 2 compatibility
+        return self.__next__()
+
+    def __next__(self):
         if self._current_iteration is None:
             self._current_iteration = self._iterate(on_item=True)
         try:
-            return self._current_iteration.next()
+            return next(self._current_iteration)
         except StopIteration:
             self._current_iteration = None
         raise StopIteration
@@ -460,7 +467,7 @@ class EntityIterator(object):
             for entity_id in self._iterate(on_item=False):
                 self._graph._bulk_update_data(txn, self._src_kind, entity_id, **updates)
             self._graph._transaction_commit(txn)
-        except Exception, e:
+        except Exception as e:
             self._graph._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
 
@@ -494,7 +501,7 @@ class EntityIterator(object):
     def dot(self, node_label=None, edge_label=None, limit=100):
         return DotExport(self, node_label, edge_label, limit)
 
-    def _dot_str(self, node_label=None, edge_label=None, limit=100):
+    def _dot_str(self, node_label=None, edge_label=None, limit=100):  # pragma : no cover
         return str(DotExport(self, node_label, edge_label, limit))
 
 
@@ -836,7 +843,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
                     prefix = build_key(KIND_INDEX, KIND_EDGE, index_id)
                     self._edge_indexes.append(ExactIndex(self, KIND_EDGE, prefix, *fields, **filters))
             self._transaction_commit(txn)
-        except Exception, e:  # pragma : no cover
+        except Exception as e:  # pragma : no cover
             self._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
         # Instantiate an optimizer (which will choose between scan and sequential scan AND (in the future) cache best index for most runned queries)
@@ -857,7 +864,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             try:
                 self._prepare_database(txn)
                 self._transaction_commit(txn)
-            except Exception, e:
+            except Exception as e:
                 self._transaction_rollback(txn)
                 raise GrapheekDataPreparationFailedException(repr(e))
         self.__initialize__()
@@ -981,7 +988,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             # Remove entity from indexes before updating data (we'll re-add it just after with new values)
             self._remove_from_all_entity_indexes(_txn, _kind, _entity_id)
             # Do the update :
-            for subkey, value in updates.items():
+            for subkey, value in list(updates.items()):
                 key = build_key(_kind, _entity_id, DATA_SUFFIX)
                 data[subkey] = value
                 self._set(_txn, key, data)
@@ -989,7 +996,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             self._add_to_all_entity_indexes(_txn, _kind, _entity_id, data)
             if release_txn:
                 self._transaction_commit(_txn)
-        except Exception, e:
+        except Exception as e:
             if release_txn:
                 self._transaction_rollback(_txn)
             raise GrapheekDataException(repr(e))
@@ -1019,7 +1026,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
         return func(self, _ctx, *aliases, **params)
 
     def _add_node(self, txn, data, node_id=None):
-        assert(type(data) == DictType)
+        assert(isinstance(data, dict))
         release_txn = False
         if txn is None:
             release_txn = True
@@ -1032,7 +1039,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             operation.set(build_key(KIND_VERTEX, node_id, DATA_SUFFIX), data)
             operation.merge(node._add_denorm_data())
             # Adding node id to proper node ids list :
-            operation.append_to_lst(build_key(METADATA_VERTEX_ID_LIST_PREFIX, node_id / CHUNK_SIZE), node_id)
+            operation.append_to_lst(build_key(METADATA_VERTEX_ID_LIST_PREFIX, node_id // CHUNK_SIZE), node_id)
             if release_txn:
                 # Applying operation (before updating indexes as indexes needs key to be updated)
                 operation.apply(txn, self)
@@ -1044,7 +1051,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
                 return node
             else:
                 return operation
-        except Exception, e:
+        except Exception as e:
             if release_txn:
                 self._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
@@ -1056,7 +1063,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             node_count = len(node_defns)
             last_node_id = self._update_inc(txn, METADATA_VERTEX_COUNTER, node_count) - 1
             first_node_id = last_node_id - node_count + 1
-            range_ids = range(first_node_id, last_node_id + 1)
+            range_ids = list(range(first_node_id, last_node_id + 1))
             for node_id, data in zip(range_ids, node_defns):
                 operation.merge(self._add_node(txn, data, node_id))
             operation.apply(txn, self)
@@ -1069,7 +1076,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             if not(silent):
                 res = [Node(node_id, self) for node_id in range_ids]
                 return res
-        except Exception, e:
+        except Exception as e:
             self._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
 
@@ -1089,7 +1096,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             # now, removing node related data and denorm data :
             operation.merge(node._remove_denorm_data())
             # Removing node id from proper node ids list :
-            operation.remove_from_lst(build_key(METADATA_VERTEX_ID_LIST_PREFIX, int(node_id) / CHUNK_SIZE), node_id)
+            operation.remove_from_lst(build_key(METADATA_VERTEX_ID_LIST_PREFIX, int(node_id) // CHUNK_SIZE), node_id)
             # Updating vertex indexes before removing data
             self._remove_from_all_entity_indexes(txn, KIND_VERTEX, node_id)
             # Now removing data
@@ -1101,12 +1108,12 @@ class BaseGraph(GraphReadWrite, GraphNx):
             # Update denorm counter :
             self._node_count -= 1
             self._transaction_commit(txn)
-        except Exception, e:
+        except Exception as e:
             self._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
 
     def _add_edge(self, txn, source, target, data=None, edge_id=None):
-        assert(isinstance(data, DictType))
+        assert(isinstance(data, dict))
         release_txn = False
         if txn is None:
             release_txn = True
@@ -1123,7 +1130,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             # Persistence and denormalization - START
             operation.set(build_key(KIND_EDGE, edge_id, DATA_SUFFIX), data)
             # Adding edge id to proper edge ids list :
-            operation.append_to_lst(build_key(METADATA_EDGE_ID_LIST_PREFIX, int(edge_id) / CHUNK_SIZE), edge_id)
+            operation.append_to_lst(build_key(METADATA_EDGE_ID_LIST_PREFIX, int(edge_id) // CHUNK_SIZE), edge_id)
             # Edge data denormalization
             edge = Edge(edge_id, self)
             operation.merge(edge._add_denorm_data(source, target))
@@ -1143,7 +1150,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
                 return edge
             else:
                 return operation
-        except Exception, e:
+        except Exception as e:
             if release_txn:
                 self._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
@@ -1155,7 +1162,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             edge_count = len(edge_defns)
             last_edge_id = self._update_inc(txn, METADATA_EDGE_COUNTER, edge_count) - 1
             first_edge_id = last_edge_id - edge_count + 1
-            range_ids = range(first_edge_id, last_edge_id + 1)
+            range_ids = list(range(first_edge_id, last_edge_id + 1))
             for edge_id, edge_defn in zip(range_ids, edge_defns):
                 source, target, data = edge_defn
                 operation.merge(self._add_edge(txn, source, target, data, edge_id=edge_id))
@@ -1168,7 +1175,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             self._transaction_commit(txn)
             if not(silent):
                 return [Edge(edge_id, self) for edge_id in range_ids]
-        except Exception, e:
+        except Exception as e:
             self._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
 
@@ -1203,7 +1210,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             operation.merge(remove_vertex_denorm_data(source, target, OUT_VERTICES_SUFFIX))
             operation.merge(remove_vertex_denorm_data(target, source, IN_VERTICES_SUFFIX))
             # Removing edge id from proper edge ids list :
-            operation.remove_from_lst(build_key(METADATA_EDGE_ID_LIST_PREFIX, edge_id / CHUNK_SIZE), edge_id)
+            operation.remove_from_lst(build_key(METADATA_EDGE_ID_LIST_PREFIX, edge_id // CHUNK_SIZE), edge_id)
             # Removing edge related lists
             operation.remove(build_key(KIND_EDGE, edge_id, IN_VERTICES_SUFFIX))
             operation.remove(build_key(KIND_EDGE, edge_id, OUT_VERTICES_SUFFIX))
@@ -1224,7 +1231,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
                 self._transaction_commit(txn)
             else:
                 return operation
-        except Exception, e:
+        except Exception as e:
             if release_txn:
                 self._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
@@ -1345,7 +1352,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
                 check_base_node(source)
                 check_base_node(target)
                 check_valid_data(data)
-        except (TypeError, ValueError), e:
+        except (TypeError, ValueError) as e:
             raise GrapheekDataException(repr(e))
         return self._bulk_add_edge(edge_defns, silent)
 
@@ -1376,7 +1383,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
     def _add_entity_index(self, _kind, *args, **filters):
         fields = list(args)
         fields.sort()
-        filter_tuples = filters.items()
+        filter_tuples = list(filters.items())
         filter_tuples.sort()
         index_signature = [fields, filter_tuples]
         index_signature_string = normalize_value(index_signature)
@@ -1421,7 +1428,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             # Everything seems to be ok, adding index to proper list
             entity_indexes.append(index)
             self._transaction_commit(txn)
-        except Exception, e:
+        except Exception as e:
             self._transaction_rollback(txn)
             raise GrapheekIndexCreationFailedException(repr(e))
 
@@ -1441,7 +1448,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
         assert(_kind in (KIND_VERTEX, KIND_EDGE))
         fields = list(args)
         fields.sort()
-        filter_tuples = kwargs.items()
+        filter_tuples = list(kwargs.items())
         filter_tuples.sort()
         index_signature = [fields, filter_tuples]
         index_signature_string = normalize_value(index_signature)
@@ -1478,7 +1485,7 @@ class BaseGraph(GraphReadWrite, GraphNx):
             # Removing index from index list :
             self._remove_from_lst(txn, METADATA_INDEX_LIST, index_id)
             self._transaction_commit(txn)
-        except Exception, e:
+        except Exception as e:
             self._transaction_rollback(txn)
             raise GrapheekIndexRemovalFailedException(repr(e))
 
