@@ -1,8 +1,5 @@
 # -*- coding:utf-8 -*-
 
-from types import BooleanType, DictType, FloatType, IntType
-from types import ListType, LongType, NoneType, StringType, TupleType, UnicodeType
-
 import zmq
 import msgpack
 
@@ -18,13 +15,25 @@ from grapheekdb.lib.exceptions import GrapheekDataException
 from grapheekdb.lib.exceptions import GrapheekUnmarshallingException
 from grapheekdb.lib.exceptions import GrapheekInvalidDataTypeException
 
+try:  # pragma : no cover
+    LONG = long
+except NameError:  # pragma : no cover
+    LONG = int
+NONETYPE = type(None)
+try:  # pragma : no cover
+    UNICODE = unicode
+except NameError:  # pragma : no cover
+    UNICODE = str
+
 
 def unmarshall(graph, item):
-    if isinstance(item, (BooleanType, FloatType, IntType, LongType, NoneType, StringType, UnicodeType)):
+    if isinstance(item, (bool, float, int, str, LONG, NONETYPE, UNICODE)):
         return item
+    if isinstance(item, bytes):  # pragma : no cover
+        return str(item, encoding='utf8')
     if isinstance(item, (ProxyNode, ProxyEdge)):
         return item
-    elif isinstance(item, DictType):
+    elif isinstance(item, dict):
         # Check if item is in fact a "special" dict (<-> handling an instance serialization)
         kind = item.get('__', None)
         if kind is not None:
@@ -42,20 +51,22 @@ def unmarshall(graph, item):
             elif kind == 'd':
                 return dict((unmarshall(graph, key), unmarshall(graph, value)) for key, value in item['d'])
         else:
-            items = [(unmarshall(graph, key), unmarshall(graph, value)) for key, value in item.items()]
+            items = [(unmarshall(graph, key), unmarshall(graph, value)) for key, value in list(item.items())]
             return dict(items)
-    elif isinstance(item, (ListType, TupleType)):
+    elif isinstance(item, (list, tuple)):
         return [unmarshall(graph, x) for x in item]
     raise GrapheekUnmarshallingException('Unknown type %s' % type(item))
 
 
 def sanitize(item):
-    if isinstance(item, (BooleanType, FloatType, IntType, LongType, NoneType, StringType, UnicodeType)):
+    if isinstance(item, (bool, float, int, str, LONG, NONETYPE, UNICODE)):
         return item
-    if isinstance(item, (DictType)):
-        items = [(sanitize(key), sanitize(value)) for key, value in item.items()]
+    if isinstance(item, bytes):  # pragma : no cover
+        return str(item, encoding='utf8')
+    if isinstance(item, dict):
+        items = [(sanitize(key), sanitize(value)) for key, value in list(item.items())]
         return dict(items)
-    elif isinstance(item, (ListType, TupleType, set)):
+    elif isinstance(item, (list, tuple, set)):
         return [sanitize(x) for x in item]
 
 
@@ -85,11 +96,15 @@ class ProxyIteratorCommon(object):
         return self
 
     def next(self):
+        # Python 2 compatibility
+        return self.__next__()
+
+    def __next__(self):
         if self._current_iteration is None:
             response = self._request()
             self._current_iteration = iter(response)
         try:
-            return self._current_iteration.next()
+            return next(self._current_iteration)
         except StopIteration:
             self._current_iteration = None
         raise StopIteration
@@ -327,10 +342,10 @@ class ProxyGraph(GraphReadWrite, GraphNx):
         self._zmq_socket.connect(address)
 
     def _request(self, commands):
-        data = msgpack.dumps(sanitize(commands))
+        data = msgpack.dumps(sanitize(commands), encoding='utf8')
         self._zmq_socket.send(data)
         raw = self._zmq_socket.recv()
-        msg = msgpack.loads(raw)
+        msg = msgpack.loads(raw, encoding='utf8')
         return unmarshall(self, msg)
 
     def v(self, entity_id):
@@ -350,7 +365,8 @@ class ProxyGraph(GraphReadWrite, GraphNx):
     def add_node(self, **kwargs):
         check_valid_data(kwargs)
         command = ['add_node', [], kwargs]
-        return self._request([command])
+        res = self._request([command])
+        return res
 
     def bulk_add_node(self, node_defns, silent=False):
         for data in node_defns:
@@ -373,7 +389,7 @@ class ProxyGraph(GraphReadWrite, GraphNx):
                 check_proxy_node(source)
                 check_proxy_node(target)
                 check_valid_data(data)
-        except (TypeError, ValueError), e:
+        except (TypeError, ValueError) as e:
             raise GrapheekDataException(repr(e))
         # Don't be suprised by [[ ... ]] instead of [ ... ]
         # Server function is expecting only one argument :
